﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2014

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Zusatzvariablen zur partnerschaftlichen Lebensform
* Mikrozensus Scientific Use File 1996

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: part96.sps
* Version: 1

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
* Lengerer, Andrea (2019): Mikrozensus Tools: Identifikation verschieden- und
  gleichgeschlechtlicher Partnerschaften in den Scientific Use Files 1973 bis 2014
  GESIS Papers 2019/09. Mannheim: GESIS.
* Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2019):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2012
  GESIS Papers 2019/01. Mannheim: GESIS.

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=1996.

* Versionsnummer.
COMPUTE vers_part=1.


*--------------------------------------------------------   Ehe   ---------------------------------------------------------.

* mit Ehepartner im Haushalt lebend.
IF EF509>0 AND EF575>0 ehe=0.
IF (EF509=1 AND (EF575=1 OR EF575=2)) OR EF509=2 ehe=1.
IF EF506=3 ehe=-2.


*--------------------------------   Partnerschaft (nichtehelich) im gemeinsamen Haushalt   --------------------------------.

*--- (1) mit Partner im Haushalt lebend, basierend auf gueltigen Angaben ---.

* Hilfsvariable ep=1, wenn Person angibt, Ehepartner der Bezugsperson zu sein.
COMPUTE ep=0.
IF EF507=2 ep=1.

* Hilfsvariable lp=1, wenn Person angibt, Lebenspartner der Bezugsperson zu sein.
COMPUTE lp=0.
IF EF39=1 lp=1.

* Hilfsvariable glp=1, wenn Lebenspartner der Bezugsperson maennlich und glp=2, wenn
  Lebenspartner der Bezugsperson weiblich ist.
IF EF39=1 AND EF32=1 glp=1.
IF EF39=1 AND EF32=2 glp=2.

* Hilfsvariable v=1, wenn Person die Angabe bei EF39 verweigert.
COMPUTE v=0.
IF EF39=9 v=1.

SORT CASES BY hhnr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / sum_ep=SUM(ep)
   / sum_lp=SUM(lp)
   / sum_glp=SUM(glp)
   / sum_v=SUM(v).

* Kontrolle:
  - Anzahl Ehepartner im Haushalt 0 oder 1 (sum_ep)
  - Anzahl Lebenspartner im Haushalt 0 oder 1 (sum_lp)
  - Geschlecht des Lebenspartners 1, 2 oder missing (sum_glp)
  - Anzahl Personen ohne Angabe im Haushalt 0 oder mehr (sum_v).
* FREQ sum_ep sum_lp sum_glp sum_v.

* Partner verschiedengeschlechtlich.
IF (EF507=1 AND sum_ep=1) OR (EF507=1 AND sum_lp=0 AND sum_v=0)
   OR (((EF507=1 AND sum_lp=1) OR EF39=1) AND ((EF557=1 AND sum_glp=1)
   OR (EF557=2 AND sum_glp=2))) OR EF37=1 OR EF39=8 vgp_ga=0.
IF ((EF507=1 AND sum_lp=1) OR EF39=1) AND ((EF557=1 AND sum_glp=2)
   OR (EF557=2 AND sum_glp=1)) vgp_ga=1.
IF (EF507=1 AND sum_ep=0 AND sum_lp=0 AND sum_v>=1) OR EF39=9 vgp_ga=-1.
IF EF506=3 vgp_ga=-2.

* Partner gleichgeschlechtlich.
IF (EF507=1 AND sum_ep=1) OR (EF507=1 AND sum_lp=0 AND sum_v=0)
   OR (((EF507=1 AND sum_lp=1) OR EF39=1) AND ((EF557=1 AND sum_glp=2)
   OR (EF557=2 AND sum_glp=1))) OR EF37=1 OR EF39=8 ggp_ga=0.
IF ((EF507=1 AND sum_lp=1) OR EF39=1) AND ((EF557=1 AND sum_glp=1)
   OR (EF557=2 AND sum_glp=2)) ggp_ga=1.
IF (EF507=1 AND sum_ep=0 AND sum_lp=0 AND sum_v>=1) OR EF39=9 ggp_ga=-1.
IF EF506=3 ggp_ga=-2.


*--- (2) mit Partner im Haushalt lebend, basierend auf Schaetzung ---.

* Vorbedingung 1: Zweifamilienhaushalt (zwei Personen im Haushalt mit EF509=1).
* Vorbedingung 2: Haushalt mit familienfremden Personen (EF541=3,4,6,7).

* Anzahl Familien im Haushalt.
COMPUTE fam=0.
IF EF509=1 fam=1.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / anz_fam=SUM(fam).

* potenzielle Partner: Personen in Zweifamilienhaushalten mit familienfremden Personen,
  im Alter von 16 Jahren und darueber, die Bezugsperson in der Familie sind und ohne
  Ehepartner im Haushalt leben, oder Kind in der Familie sind.
COMPUTE par=0.
IF anz_fam=2 AND (EF541=3 OR EF541=4 OR EF541=6 OR EF541=7) AND EF30>=16
   AND ((EF509=1 AND EF575>=4 AND EF575<=9) OR EF509=3) par=1.

* Sortierung potenzieller Partnern in der Familie nach folgender Reihenfolge: zuerst Bezugsperson,
  dann Kinder, bei mehreren Kindern zuerst aeltestes Kind.
SORT CASES BY hhnr (A) EF28 (A) par(D) EF509 (A) EF30 (D).

* Hilfsvariablen zur Berechnung der Altersdifferenz zwischen potenziellen Partnern:
  fortlaufende Nummer der Familie im Haushalt (fnr)
  fortlaufende Nummer des potenziellen Partners in der Familie (pnrf).
IF $CASENUM=1 OR hhnr~=LAG(hhnr) fnr=1.
IF hhnr=LAG(hhnr) AND EF28~=LAG(EF28) fnr=fnr+1.
LEAVE fnr.
EXECUTE.
IF $CASENUM=1 OR hhnr~=LAG(hhnr) OR EF28~=LAG(EF28) pnrf=par.
IF hhnr=LAG(hhnr) AND EF28=LAG(EF28) pnrf=pnrf+par.
LEAVE pnrf.
IF par=0 pnrf=0.

* Berechnung der Altersdifferenz zwischen allen potenziellen Partnern im Haushalt, die unterschied-
  lichen Familien angehoeren (wobei die ersten drei potenziellen Partner pro Familie beruecksichtigt
  werden).

* zunaechst wird das Alter der potenziellen Partner einer Familie den potenziellen Partnern der
  anderen Familie im Haushalt zugespielt.
IF pnrf=1 altpp1=EF30.
IF pnrf=2 altpp2=EF30.
IF pnrf=3 altpp3=EF30.
SORT CASES BY hhnr fnr.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr fnr
   / altpp1ef=MAX(altpp1)
   / altpp2ef=MAX(altpp2)
   / altpp3ef=MAX(altpp3).

RECODE fnr (1=2) (2=1) INTO fnr2.

SORT CASES BY hhnr fnr2.
TEMP.
SEL IF pnrf=1.
SAVE OUTFILE='pfad_kumdat/alt_tmp96.sav'
   / KEEP=hhnr fnr2 altpp1ef altpp2ef altpp3ef
   / RENAME (fnr2 altpp1ef altpp2ef altpp3ef=fnr altpp1af altpp2af altpp3af).

SORT CASES BY hhnr fnr.
MATCH FILES / FILE=*
   / TABLE='pfad_kumdat/alt_tmp96.sav'
   / BY hhnr fnr.
EXECUTE.

* dann wird die Altersdifferenz zwischen allen potenziellen Partnern im Haushalt ermittelt (wobei
  aa11 die Altersdifferenz zwischen dem ersten Partner der einen und dem ersten Partner der
  anderen Familie, aa12 die Altersdifferenz zwischen dem ersten Partner der einen und dem zweiten
  Partner der anderen Familie wiedergibt, ...).
COMPUTE aa11=ABS(altpp1ef-altpp1af).
COMPUTE aa12=ABS(altpp1ef-altpp2af).
COMPUTE aa13=ABS(altpp1ef-altpp3af).
COMPUTE aa21=ABS(altpp2ef-altpp1af).
COMPUTE aa22=ABS(altpp2ef-altpp2af).
COMPUTE aa23=ABS(altpp2ef-altpp3af).
COMPUTE aa31=ABS(altpp3ef-altpp1af).
COMPUTE aa32=ABS(altpp3ef-altpp2af).
COMPUTE aa33=ABS(altpp3ef-altpp3af).

* Altersdifferenz zu nicht vorhandenen potenziellen Partnern wird auf Code 99 gesetzt.
RECODE aa11 aa12 aa13 aa21 aa22 aa23 aa31 aa32 aa33 (SYSMIS=99) (ELSE=COPY).

* Identifikation potenzieller Partner mit der geringsten Altersdifferenz, nach folgenden Regeln:
  - fuer beide potenzielle Partner darf es in der jeweils anderen Familie keinen anderen potenziellen
    Partner geben, zu dem die Altersdifferenz geringer ist
  - die Altersdifferenz zu allen anderen potenziellen Partnern muss mindestens x+1 Jahre groesser
    sein.
COMPUTE x=9.
COMPUTE par2=0.
DO IF pnrf=1 AND (aa11+x)<aa12 AND (aa11+x)<aa13 AND (aa11+x)<aa21 AND (aa11+x)<aa31.
+   COMPUTE par2=1.
+   COMPUTE altab=aa11.
END IF.
DO IF pnrf=1 AND (aa12+x)<aa11 AND (aa12+x)<aa13 AND (aa12+x)<aa22 AND (aa12+x)<aa32.
+   COMPUTE par2=1.
+   COMPUTE altab=aa12.
END IF.
DO IF pnrf=1 AND (aa13+x)<aa11 AND (aa13+x)<aa12 AND (aa13+x)<aa23 AND (aa13+x)<aa33.
+   COMPUTE par2=1.
+   COMPUTE altab=aa13.
END IF.
DO IF pnrf=2 AND (aa21+x)<aa22 AND (aa21+x)<aa23 AND (aa21+x)<aa11 AND (aa21+x)<aa31.
+   COMPUTE par2=1.
+   COMPUTE altab=aa21.
END IF.
DO IF pnrf=2 AND (aa22+x)<aa21 AND (aa22+x)<aa23 AND (aa22+x)<aa12 AND (aa22+x)<aa32.
+   COMPUTE par2=1.
+   COMPUTE altab=aa22.
END IF.
DO IF pnrf=2 AND (aa23+x)<aa21 AND (aa23+x)<aa22 AND (aa23+x)<aa13 AND (aa23+x)<aa33.
+   COMPUTE par2=1.
+   COMPUTE altab=aa23.
END IF.
DO IF pnrf=3 AND (aa31+x)<aa32 AND (aa31+x)<aa33 AND (aa31+x)<aa11 AND (aa31+x)<aa21.
+   COMPUTE par2=1.
+   COMPUTE altab=aa31.
END IF.
DO IF pnrf=3 AND (aa32+x)<aa31 AND (aa32+x)<aa33 AND (aa32+x)<aa12 AND (aa32+x)<aa22.
+   COMPUTE par2=1.
+   COMPUTE altab=aa32.
END IF.
DO IF pnrf=3 AND (aa33+x)<aa31 AND (aa33+x)<aa32 AND (aa33+x)<aa13 AND (aa33+x)<aa23.
+   COMPUTE par2=1.
+   COMPUTE altab=aa33.
END IF.

* in Haushalten, in denen sowohl die Bezugspersonen als auch die Kinder beider Familien potenzielle
  Partner (par2=1) sind, werden nur die Bezugspersonen als Partner gezaehlt.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / sum_par2=SUM(par2).
IF sum_par2=4 AND EF509=3 par2=0.

* Kontrolle: 0 oder 2 Personen im Haushalt mit par2=1.
* AGGREGATE OUTFILE=* MODE=ADDVARIABLES OVERWRITE=YES
   / PRESORTED
   / BREAK hhnr
   / sum_par2=SUM(par2).
* FREQ sum_par2.

* Geschlecht der potenziellen Partner im Haushalt.
IF par2=1 gesch_p=EF32.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK hhnr
   / gesch_p1=FIRST(gesch_p)
   / gesch_p2=LAST(gesch_p).

* Partner verschiedengeschlechtlich, Altersdifferenz unerheblich.
IF EF509>=1 AND EF541<=7 AND EF575>=1 vgp_s1=0.
IF par2=1 AND gesch_p1~=gesch_p2 vgp_s1=1.
IF EF506=3 vgp_s1=-2.

* Partner verschiedengeschlechtlich, Altersdifferenz unter 18 Jahren.
IF EF509>=1 AND EF541<=7 AND EF575>=1 vgp_s2=0.
IF par2=1 AND altab<18 AND gesch_p1~=gesch_p2 vgp_s2=1.
IF EF506=3 vgp_s2=-2.

* Partner gleichgeschlechtlich, Altersdifferenz unerheblich.
IF EF509>=1 AND EF541<=7 AND EF575>=1 ggp_s1=0.
IF par2=1 AND gesch_p1=gesch_p2 ggp_s1=1.
IF EF506=3 ggp_s1=-2.

* Partner gleichgeschlechtlich, Altersdifferenz unter 18 Jahren.
IF EF509>=1 AND EF541<=7 AND EF575>=1 ggp_s2=0.
IF par2=1 AND altab<18 AND gesch_p1=gesch_p2 ggp_s2=1.
IF EF506=3 ggp_s2=-2.
EXECUTE.


*--- (3) mit Partner im Haushalt lebend, basierend auf gueltigen und imputierten Angaben ---.

* Partner verschiedengeschlechtlich.
COMPUTE vgp_gia=vgp_ga.
IF vgp_ga=-1 AND vgp_s1=0 vgp_gia=0.
IF vgp_ga=-1 AND vgp_s1=1 vgp_gia=1.

* Partner gleichgeschlechtlich.
COMPUTE ggp_gia=ggp_ga.
IF ggp_ga=-1 AND ggp_s1=0 ggp_gia=0.
IF ggp_ga=-1 AND ggp_s1=1 ggp_gia=1.
EXECUTE.


*---------------------------------   Ausschluss temporaerer Hilfsvariablen und -dateien   ---------------------------------.

DELETE VARIABLES  ep  lp  glp  v  sum_ep  sum_lp  sum_glp  sum_v
   fam  anz_fam  par  fnr  pnrf  altpp1  altpp2  altpp3  altpp1ef  altpp2ef  altpp3ef
   altpp1af  altpp2af  altpp3af  fnr2  aa11  aa12  aa13  aa21  aa22  aa23  aa31  aa32 aa33
   x  par2  sum_par2  altab  gesch_p  gesch_p1  gesch_p2.
EXECUTE.


ERASE FILE='pfad_kumdat/alt_tmp96.sav'.

